@@ -4,17 +4,21 @@ from enum import Enum
 from typing import Dict, List, Tuple, Union
 from functools import partial, partialmethod, wraps
 
-
 import hid
 
+from bitvector import BitVector, BitField
 from loguru import logger
 
-from .bitvector import BitVector, BitField
 from .constants import EMBRAVA_VENDOR_IDS, FlashSpeed, END_OF_COMMAND, COMMAND_LENGTH
 from .exceptions import BlyncLightInUse, BlyncLightNotFound, BlyncLightUnknownDevice
 
 
 class BlyncCommand(BitField):
+    """BlyncCommand is descriptor which will conditionally write
+    the contents of the BlyncLight to the target device when a field
+    is updated. 
+    """
+
     def __set__(self, obj, value) -> None:
         super().__set__(obj, value)
         try:
@@ -23,11 +27,29 @@ class BlyncCommand(BitField):
             logger.error(f"Failed to update {obj!r} after setting {self.name}")
 
 
+class BlyncColor(BlyncCommand):
+    """An eight-bit unsigned integer color value."""
+
+
+class BlyncOff(BlyncCommand):
+    """Single bit toggle that toggles the light on and off."""
+
+
+class BlyncDim(BlyncCommand):
+    """Single bit toggle that dims the light when set."""
+
+
+class BlyncFlash(BlyncCommand):
+    """Single bit toggle that enables flash mode when set."""
+
+
 class BlyncSpeed(BlyncCommand):
-    # speed gets it's own descriptor implementation due to it's being a
-    # flag instead of a "value" and this was easier than trying to
-    # shoehorn the logic into the BlyncCommand descriptor.
-    #
+
+    """BlyncSpeed descriptor sets and gets the speed field of a BlyncLight
+    in-memory represenation. The speed field is a bit flag whose valid
+    values are 1, 2, and 4 (b001, b010, b100). 
+    """
+
     # If more than one bit is set in the three bit speed field and the
     # flash bit is set, the light will flash exceedingly fast. If speed
     # is zero, the light turns off regardless of off == 0. Bug in the
@@ -42,6 +64,26 @@ class BlyncSpeed(BlyncCommand):
         super().__set__(obj, speed)
 
 
+class BlyncRepeat(BlyncCommand):
+    """Single bit that toggles music repeat on and off."""
+
+
+class BlyncPlay(BlyncCommand):
+    """Single bit that toggles music start and stop."""
+
+
+class BlyncMusic(BlyncCommand):
+    """Four bit field that chooses which song to play."""
+
+
+class BlyncVolume(BlyncCommand):
+    """Four bit field that controls the volume used to play a song."""
+
+
+class BlyncMute(BlyncCommand):
+    """Single bit toggles that mutes and unmutes playing music."""
+
+
 class BlyncLight(BitVector):
     """BlyncLight
 
@@ -139,7 +181,8 @@ class BlyncLight(BitVector):
 
     @classmethod
     def available_lights(cls) -> List[Dict[str, Union[int, str]]]:
-        """
+        """Returns a list of dictionaries describing all the BlyncLight
+        devices found. 
         """
         lights = []
         for vendor_id in EMBRAVA_VENDOR_IDS:
@@ -148,10 +191,16 @@ class BlyncLight(BitVector):
 
     @classmethod
     def get_light(cls, light_id: int = 0, immediate: bool = True):
-        """
+        """Returns a configured BlyncLight for the supplied `light_id`
+        which is an index into the list of available devices discovered.
+
+        :param light_id: int
+        :param immediate: bool
+
         Raises
-        - KeyError
-        - ValueError
+        - BlyncLightNotFound
+        - BlyncLightInUse
+        - BlyncLightUnknown
         """
         try:
             light = cls.available_lights()[light_id]
@@ -161,6 +210,22 @@ class BlyncLight(BitVector):
         return cls(light["vendor_id"], light["product_id"], immediate)
 
     def __init__(self, vendor_id: int, product_id: int, immediate: bool = False):
+        """Returns a configured BlyncLight.
+
+        The `immediate` argument initializes the light's immediate property. 
+        If `immediate` is False, modified state is not written to the light
+        until the user calls BlyncLight.update().  If immediate is True, any
+        changes are written to the light immediately.
+
+        :param vendor_id: int
+        :param product_id: int
+
+        Raises
+        - BlyncLightNotFound
+        - BlyncLightInUse
+        - BlyncLightUnknown
+        """
+
         super().__init__(size=COMMAND_LENGTH * 8)
 
         self.vendor_id = vendor_id
@@ -177,18 +242,18 @@ class BlyncLight(BitVector):
         self.reset()
         self.immediate = immediate
 
-    red = BlyncCommand(56, 8)
-    blue = BlyncCommand(48, 8)
-    green = BlyncCommand(40, 8)
-    off = BlyncCommand(32, 1)
-    dim = BlyncCommand(33, 1)
-    flash = BlyncCommand(34, 1)
+    red = BlyncColor(56, 8)
+    blue = BlyncColor(48, 8)
+    green = BlyncColor(40, 8)
+    off = BlyncOff(32, 1)
+    dim = BlyncDim(33, 1)
+    flash = BlyncFlash(34, 1)
     speed = BlyncSpeed(35, 3)
-    repeat = BlyncCommand(29, 1)
-    play = BlyncCommand(28, 1)
-    music = BlyncCommand(24, 4)
-    mute = BlyncCommand(23, 1)
-    volume = BlyncCommand(18, 4)
+    repeat = BlyncRepeat(29, 1)
+    play = BlyncPlay(28, 1)
+    music = BlyncMusic(24, 4)
+    mute = BlyncMute(23, 1)
+    volume = BlyncVolume(18, 4)
 
     def __repr__(self):
         return f"{self.__class__.__name__}(product_id=0x{self.product_id:04x}, vendor_id=0x{self.product_id:04x})"
@@ -204,17 +269,25 @@ class BlyncLight(BitVector):
         self.device.close()
 
     def update(self, force: bool = False) -> None:
-        """
+        """Write the current in-memory representation of the light's state
+        to the target light. If immediate or force is True, the write is attempted.
+        If not force and not self.immediate, the write is deferred.
+
+        :param force: bool
         """
         if self.immediate or force:
             self.device.write(self.bytes)
             return
 
     def reset(self, flush: bool = True) -> None:
-        """
+        """Resets the in-memory representation of the light's state to a known
+        state (off=1, speed=1, mute=1, all other bits zero) and writes the state
+        to the target light depending on the value of `flush`. 
+
+        :param flush: bool
         """
         with self.updates_paused():
-            self[64:72] = 0
+            self[64:72] = 0  # this should always be zero
             self.red = 0
             self.blue = 0
             self.green = 0
@@ -225,7 +298,7 @@ class BlyncLight(BitVector):
             self.repeat = 0
             self.play = 0
             self.music = 0
-            self.mute = 0
+            self.mute = 1
             self.volume = 0
             self[0:16] = END_OF_COMMAND
 
@@ -233,10 +306,13 @@ class BlyncLight(BitVector):
 
     @property
     def identifier(self):
+        """Hexadecimal concatenation of vendor_id and product_id."""
         return f"0x{self.vendor_id:04x}:0x{self.product_id:04x}"
 
     @property
     def status(self) -> Dict[str, str]:
+        """A dictionary representation of the bit vector.
+        """
         try:
             return self._status
         except AttributeError:
@@ -260,7 +336,10 @@ class BlyncLight(BitVector):
         return self._status
 
     @property
-    def immediate(self):
+    def immediate(self) -> bool:
+        """Property which controls the frequency that state is written
+        to the target light.
+        """
         return getattr(self, "_immediate", False)
 
     @immediate.setter
@@ -270,6 +349,8 @@ class BlyncLight(BitVector):
 
     @property
     def on(self) -> bool:
+        """Reverse logic getter/setter for `off` property.
+        """
         return 0 if self.off else 1
 
     @on.setter
@@ -278,6 +359,8 @@ class BlyncLight(BitVector):
 
     @property
     def bright(self) -> bool:
+        """Reverse logic getter/setter for `dim` property.
+        """
         return not self.dim
 
     @bright.setter
@@ -286,6 +369,7 @@ class BlyncLight(BitVector):
 
     @property
     def color(self) -> Tuple[int, int, int]:
+        """Returns a 3-tuple of integers: (red, blue, green)."""
         return (self.red, self.blue, self.green)
 
     @color.setter
@@ -313,11 +397,16 @@ class BlyncLight(BitVector):
         except AttributeError:
             pass
 
-        raise TypeError("Expecting a 24-bit color or tuple of bytes.")
+        raise TypeError("Expected a 24-bit color or tuple of bytes.")
 
     @contextmanager
     def updates_paused(self):
-        """Pauses updates to the light until the context manager exits.
+        """Context manager that allows bulk updates to the target lights'
+        in-memory state. The context manager saves the current value of
+        `immediate` and sets `immediate` to False.  This reduces the number
+        writes to the target device and "hides" in-between states that
+        may be undesirable. On exit from the context manager, `immediate`
+        is restored to it's previous value.
         """
         imm = self.immediate
         self.immediate = False
